@@ -6,7 +6,7 @@ from oscar.core.loading import get_class
 
 class OffersDashboardConfig(apps.OffersDashboardConfig):
     label = 'offers_dashboard'
-    name = 'ms_oscar_flash_offer.apps.dashboard.offers'
+    name = 'ms_oscar_flash_offer.dashboard.offers'
     verbose_name = 'Offers dashboard'
 
     def ready(self):
